import bson
import base64
from datetime import datetime

from django.shortcuts import render
from .models import License


class LicenceMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        path = request.get_full_path()
        if path.startswith("/api"):
            if self.is_valid():
                return self.get_response(request)

            return render(request, 'licence_expired.html')

        return self.get_response(request)

        

    def is_valid(self):
        lics = License.objects.filter(active=True).all()
        for lic in lics:
            buf = base64.b64decode(lic.key)
            obj = bson.loads(buf)

            if obj["secret"] != 13579:
                continue

            exp = datetime.fromisoformat(obj["exp"])
            now = datetime.now()

            if exp < now:
                continue

            return True

        return False